import { apiRequest } from './helpers';
import {GetUsersForRooms, Room, RoomEdit, RoomEditDTO} from '../types/rooms';

export const getUpcomingRooms = (locale: string, token: string): Promise<Room[]> => apiRequest({
    url: '/home/upcomingsessionsall',
    method: 'post',
    data: {
        sessionType: 'room'
    },
    locale,
    token
});

export const getRecentRooms = (locale: string, token: string): Promise<Room[]> => apiRequest({
    url: '/home/historicalmeetings',
    method: 'post',
    data: {
        sessionType: 'room'
    },
    locale,
    token
});

export const getRoomDetails = (locale: string, token: string, id: number): Promise<Room> => apiRequest({
    url: '/home/room',
    method: 'post',
    data: { id },
    locale,
    token
});

export const deleteRoomClient = (locale: string, token: string, data: { sessionId: number, clientUserId: number }): Promise<any> => apiRequest({
    url: '/home/deleteclientfromroom',
    method: 'post',
    data,
    locale,
    token
});

export const deleteRoomSupervisor = (locale: string, token: string, data: { sessionId: number, supervisorUserId: number }): Promise<any> => apiRequest({
    url: '/home/deletesupervisorfromroom',
    method: 'post',
    data,
    locale,
    token
});

export const becomeRoomClient = (locale: string, token: string, data: { sessionId: number, clientUserId: number }): Promise<any> => apiRequest({
    url: '/home/becomeroomclient',
    method: 'post',
    data,
    locale,
    token
});

export const becomeRoomSupervisor = (locale: string, token: string, data: { sessionId: number, supervisorUserId: number }): Promise<any> => apiRequest({
    url: '/home/becomeroomsupervisor',
    method: 'post',
    data,
    locale,
    token
});

export const getUsersList = (locale: string, token: string, data: { template: string }): Promise<GetUsersForRooms> => apiRequest({
    url: '/home/findusersforroom',
    method: 'post',
    data,
    locale,
    token
});

export const addClient = (locale: string, token: string, data: { sessionId: number, clientUserId: number }): Promise<any> => apiRequest({
    url: '/home/addclienttoroom',
    method: 'post',
    data,
    locale,
    token
});

export const addSupervisor = (locale: string, token: string, data: { sessionId: number, supervisorUserId: number }): Promise<any> => apiRequest({
    url: '/home/addsupervisortoroom',
    method: 'post',
    data,
    locale,
    token
});

export const createRoom = (locale: string, token: string): Promise<any> => apiRequest({
    url: '/home/createroom',
    method: 'post',
    locale,
    token
});

export const updateRoom = (locale: string, token: string, data: RoomEdit): Promise<any> => apiRequest({
    url: '/home/updateroom',
    method: 'post',
    data,
    locale,
    token
});

export const getRoomById = (locale: string, token: string, id: number): Promise<RoomEditDTO> => apiRequest({
    url: '/home/getroomforedit',
    method: 'post',
    data: { id },
    locale,
    token
});
