import {
    type IRemoteVideoTrack,
    useIsConnected, useLocalCameraTrack, useLocalMicrophoneTrack, usePublish,
    useRemoteAudioTracks,
    useRemoteUsers,
    useRemoteVideoTracks
} from 'agora-rtc-react';
import { LocalUser } from './LocalUser';
import { RemoteVideoPlayer } from './RemoteVideoPlayer';

type UsersGroupPanelProps = {
    calling: boolean;
    micOn: boolean;
    cameraOn: boolean;
};

export const UsersGroupPanel = ({ calling, micOn, cameraOn }: UsersGroupPanelProps) => {
    const isConnected = useIsConnected();
    const remoteUsers = useRemoteUsers();
    const { localMicrophoneTrack } = useLocalMicrophoneTrack(micOn);
    const { localCameraTrack } = useLocalCameraTrack(cameraOn);
    const { audioTracks } = useRemoteAudioTracks(remoteUsers);

    usePublish([localMicrophoneTrack, localCameraTrack]);
    audioTracks.map(track => track.play());

    return calling && isConnected && remoteUsers ? (
        <div className={`b-agora__remote_groups gr-${remoteUsers.length + 1}`}>
            <div>
                <LocalUser
                    audioTrack={localMicrophoneTrack}
                    cameraOn={cameraOn}
                    micOn={micOn}
                    videoTrack={localCameraTrack}
                />
            </div>
            {remoteUsers.length > 0 && remoteUsers.map(({ uid, videoTrack }) => (
                <div key={uid}>
                    <RemoteVideoPlayer track={videoTrack} />
                </div>
            ))}
        </div>
    ) : null;
}
